@@ -128,7 +128,7 @@ vcsExtract <- function(object){
   ################################################
   cat(paste(rep("=",nmaxchar), collapse = ""))
   cat(paste("\n",rlt,"Multivariate Linear Mixed Model fit by REML",rlt,"\n", collapse = ""))
-  cat(paste(rlh," sommer 4.2 ",rlh, "\n", collapse = ""))
+  cat(paste(rlh," sommer 4.3 ",rlh, "\n", collapse = ""))
   cat(paste(rep("=",nmaxchar), collapse = ""))
   cat("\n")
   cat("")
@@ -211,7 +211,7 @@ vcsExtract <- function(object){
   ################################################
   cat(paste(rep("=",nmaxchar), collapse = ""))
   cat(paste("\n",rlt,"Multivariate Linear Mixed Model fit by REML",rlt,"\n", collapse = ""))
-  cat(paste(rlh," sommer 4.2 ",rlh, "\n", collapse = ""))
+  cat(paste(rlh," sommer 4.3 ",rlh, "\n", collapse = ""))
   cat(paste(rep("=",nmaxchar), collapse = ""))
   cat("\n")
   cat("")
@@ -720,16 +720,11 @@ plot.mmec <- function(x, stnd=TRUE, ...) {
 .onAttach = function(library, pkg)
 {
   Rv = R.Version()
-  if(!exists("getRversion", baseenv()) || (getRversion() < "2.1"))
-    stop("This package requires R 2.1 or later")
-  # assign(".sommer.home", file.path(library, pkg),
-  #        pos=match("package:sommer", search()))
-  # value = "4.2.1 (2023-04-01)" # usually 4 months after it expires
-  #
-  # assign(".sommer.version", value, pos=match("package:sommer", search()))   https://doi.org/10.1371/journal.pone.0156744
+  if(!exists("getRversion", baseenv()) || (getRversion() < "3.5.0"))
+    stop("This package requires R 3.5.0 or later")
   if(interactive()) {
     packageStartupMessage(blue(paste("[]==================================================================[]")),appendLF=TRUE)
-    packageStartupMessage(blue(paste("[]   Solving Mixed Model Equations in R (sommer) 4.3.1 (2023-06-01) []",sep="")),appendLF=TRUE)
+    packageStartupMessage(blue(paste("[]   Solving Mixed Model Equations in R (sommer) 4.3.2 (2023-09-01) []",sep="")),appendLF=TRUE)
     packageStartupMessage(blue(paste("[]   ------------- Multivariate Linear Mixed Models --------------  []")),appendLF=TRUE)
     packageStartupMessage(paste0(blue("[]   Author: Giovanny Covarrubias-Pazaran",paste0(bgGreen(white(" ")), bgWhite(magenta("*")), bgRed(white(" "))),"                      []")),appendLF=TRUE)
     packageStartupMessage(blue("[]   Published: PLoS ONE 2016, 11(6):1-15                           []"),appendLF=TRUE)
@@ -739,7 +734,7 @@ plot.mmec <- function(x, stnd=TRUE, ...) {
     packageStartupMessage(blue(paste("[]==================================================================[]")),appendLF=TRUE)
     packageStartupMessage(blue("sommer is updated on CRAN every 4-months due to CRAN policies"),appendLF=TRUE)
     packageStartupMessage(blue("Current source is available at https://github.com/covaruber/sommer"),appendLF=TRUE)
-    packageStartupMessage(blue("If needed install as: devtools::install_github('covaruber/sommer')"),appendLF=TRUE)
+    packageStartupMessage(blue("If needed, install as: devtools::install_github('covaruber/sommer')"),appendLF=TRUE)
 
   }
   invisible()
